@@ -1,4 +1,4 @@
-from typing import List
+"""Parse Task definition."""
 from typing import TypeVar
 
 from dkist_processing_common.models.constants import BudName
@@ -57,7 +57,7 @@ class ParseL0TestInputData(ParseL0InputData):
         return L0FitsAccess
 
     @property
-    def tag_flowers(self) -> List[S]:
+    def tag_flowers(self) -> list[S]:
         return super().tag_flowers + [
             SingleValueSingleKeyFlower(
                 tag_stem_name=StemName.task.value, metadata_key="ip_task_type"
@@ -66,7 +66,7 @@ class ParseL0TestInputData(ParseL0InputData):
         ]
 
     @property
-    def constant_flowers(self) -> List[S]:
+    def constant_flowers(self) -> list[S]:
         return super().constant_flowers + [
             TotalDspsRepeatsBud(),
             PickyDummyBud(stem_name="PICKY_BUD"),
