@@ -7,6 +7,10 @@ from dkist_processing_test.tasks.fail import FailTask
 
 
 fail = Workflow(
-    process_category="test", process_name="fail", workflow_package=__package__, tags=["test"]
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="fail",
+    workflow_package=__package__,
 )
 fail.add_node(task=FailTask, upstreams=None)
