@@ -8,13 +8,21 @@ from dkist_processing_test.tasks.noop import NoOpTask2
 
 
 noop = Workflow(
-    process_category="test", process_name="noop", workflow_package=__package__, tags=["test"]
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="noop",
+    workflow_package=__package__,
 )
 noop.add_node(task=NoOpTask, upstreams=None)
 
 
 noop_flow = Workflow(
-    process_category="test", process_name="noop_flow", workflow_package=__package__, tags=["test"]
+    input_data="input",
+    output_data="output",
+    category="test",
+    detail="noop-flow",
+    workflow_package=__package__,
 )
 noop_flow.add_node(task=NoOpTask, upstreams=None)
 noop_flow.add_node(task=NoOpTask2, upstreams=NoOpTask)
